import classNames from 'classnames'
/**
 * A Fieldset element to contain a group of checkboxes or radio buttons.  The error is displayed below the fieldset.
 *
 * [Designs](https://www.figma.com/file/k8HLf9t06G8QtlMzQlgHGk/RPF-Design-System---Component-Library?type=design&node-id=526-1283&mode=design&t=8WXVu4Nk5Ar3JL3U-4)
 *
 * */
export default {
  title: 'Components/Form/Fieldset',
  tags: ['autodocs'],
  argTypes: {
    disabled: {
      control: 'boolean',
    },
    error: { control: 'boolean' },
    fullWidth: { control: 'boolean' },
    inputType: {
      options: ["checkbox", "radio"],
      control: { type: "select" },
     },
  },
  args: {
    disabled: false,
    error: false,
    fullWidth: false,
    inputType: "checkbox",
  },
}

const TextTemplate = ({ disabled, error, fullWidth, inputType }) => {
  const classnames_wrapper = classNames('rpf-fieldset', {
    'rpf-fieldset--error': error,
    'rpf-fieldset--disabled': disabled,
    'rpf-fieldset--full-width': fullWidth,
  })
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })

  return `
    <fieldset class="${classnames_wrapper}" ${disabled ? ' disabled' : ''} >
      <legend class="${classnames_label}">
        Coding languages
        <small class="rpf-label__hint">Please select all coding languages you know</small>
      </legend>
      <div class="rpf-fieldset__inputs">
        <label class="rpf-input-${ inputType }">
          <input type="${ inputType }" name="language" value="python" checked} />
          Python
        </label>
        <label class="rpf-input-${ inputType }">
          <input type="${ inputType }" name="language" value="ruby" />
          Ruby
        </label>
        <label class="rpf-input-${ inputType }">
          <input type="${ inputType }" name="language" value="javascript" />
          JavaScript
        </label>
      </div>
      ${
        error
          ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">error</span>Error: You must choose at least one language</div>'
          : ''
      }
    </fieldset>
  `
}

export const Default = TextTemplate.bind({})
Default.args = {}

export const Error = TextTemplate.bind({})
Error.args = {
  error: true,
}

export const Disabled = TextTemplate.bind({})
Disabled.args = {
  disabled: true,
}

export const FullWidth = TextTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}

export const DisabledAndFullWidth = TextTemplate.bind({})
DisabledAndFullWidth.args = {
  disabled: true,
  fullWidth: true,
}

export const CheckboxInputType = TextTemplate.bind({})
CheckboxInputType.args = {
  inputType: "checkbox"
}

export const RadioInputType = TextTemplate.bind({})
RadioInputType.args = {
  inputType: "radio"
}
