import classNames from 'classnames'
/**
 * The single radio input, shown here with a label.  There are no error styles as radio buttons should be part of a fieldset.

 * **Note** Radio buttons do not make sense as stand-alone components and should normally be part of a [fieldset](/?path=/docs/components-form-fieldset--default).
 *
 * [Designs](https://www.figma.com/file/k8HLf9t06G8QtlMzQlgHGk/RPF-Design-System---Component-Library?type=design&node-id=526-1396&mode=design&t=8WXVu4Nk5Ar3JL3U-4)
 * */
export default {
  title: 'Components/Form/RadioInput',
  tags: ['autodocs'],
  argTypes: {
    checked: { control: 'boolean', },
    disabled: { control: 'boolean', },
    fullWidth: { control: 'boolean' },
  },
  args: {
    checked: false,
    disabled: false,
    fullWidth: false,
  },
}

const TextTemplate = ({ checked, disabled, fullWidth }) => {
  const classnames_label = classNames('rpf-input-radio', {
    'rpf-input-radio--disabled': disabled,
    'rpf-input--full-width': fullWidth,
  })

  return `
    <label class="${classnames_label} ">
      <input type="radio" name="accept_terms" value="1" ${checked ? ' checked' : ''} ${disabled ? ' disabled' : ''} />
      I accept the terms
    </label>
    `
}

export const Default = TextTemplate.bind({})
Default.args = {}

export const Disabled = TextTemplate.bind({})
Disabled.args = {
  disabled: true,
}

export const Checked = TextTemplate.bind({})
Checked.args = {
  checked: true,
}

export const FullWidth = TextTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}

export const DisabledAndFullWidth = TextTemplate.bind({})
DisabledAndFullWidth.args = {
  disabled: true,
  fullWidth: true,
}
